import * as d3 from 'd3';

function renderData(dataElements) {

    let width = 600;
    let height = 500;
    let offset = 200;

    let data = new Map();
    dataElements.forEach(element => {
        data.set(element.Age_Group, +element.Birth_Rate_per_1000);
    });
    let dt = Array.from(data.entries());
    for (let i = 0; i < dt.length; i++) {
        dt[i].push(i);
    }

    let margin = ({ top: 45, right: 25, bottom: 45, left: 45 });

    let x = d3.scaleBand()
        .domain(data.keys())
        .range([margin.left, width - margin.right])
        .paddingInner(0.07);

    let y = d3.scaleLinear()
        .domain([0, d3.max(data.values())])
        .range([height - margin.bottom, margin.top]);

    // function with g arg assigned to xAxis
    let xAxis = g => g
        .attr("transform", `translate(0,${height - margin.bottom})`)
        .call(d3.axisBottom(x));

    // function with g arg assigned to yAxis
    let yAxis = g => g
        .attr("transform", `translate(${margin.left},0)`)
        .call(d3.axisLeft(y));

    const svg = d3.select("body")
        .append("svg")
        .attr("width", width)
        .attr('height', height);

    svg.append("g")
        .call(xAxis);

    svg.append("g")
        .call(yAxis);

    svg.append("text")
        .attr("fill", "black")
        .attr("x", offset - 20)
        .attr("y", "30")
        .style("font-size", "18px")
        .text("Birth Rates per 1000 in 2016 in California.");

  // Add tooltips
    let showTt = (e, d) => {
        svg.append("text")
            .attr("id", "t1")
            .attr("x", function() { return x(d[0]); })
            .attr("y", function() { return y(d[1]); })
            .style("fill", "black")
      			.style("font-size","14px")
            .style("border-radius", "2px")
            .style("padding", "5px")
            .text(function() {
                return "Age Group " + d[0]; // Value of the text
            });
    }
    
    let hideTt = (e, d) => {
        d3.select("#t1").remove();
    }

    svg.selectAll("rect")
        .data(dt)
        .enter()
        .append("rect")
        .attr("transform", `translate(0, ${y()})`)
        .attr("fill", "blue")
        .attr("width", x.bandwidth())
        .attr("height", d => (height - y(d[1]) - margin.top))
        .attr("x", d => x(d[0]))
        .attr("y", d => y(d[1]))
        .on("mouseenter", showTt)
        .on("mouseleave", hideTt);

    svg.append("text")
        .attr("fill", "black")
        .attr("x", offset + 100)
        .attr("y", height - 5)
        .style("font-size", "14px")
        .text("Age");

    svg.append("text")
        .attr("fill", "black")
        .attr("x", "5")
        .attr("y", "-10")
        .attr("transform", "translate(30, 300) rotate(270)")
        .style("font-size", "14px")
        .text("Count");
}

d3.csv(
    "https://gist.githubusercontent.com/olga-kondr/1f16fc41e97c3c3d884ceb43eaa477f1/raw/faafab104b07c110012b4fe61cc5d30d0fd52260/Birth_Rate",
).then(data => renderData(data)); 
